@@ -69,20 +69,23 @@ use super::offset::libc_posix_fallocate;
 #[cfg(target_os = "linux")]
 use super::rand::GetRandomFlags;
 use super::{
-    conv::{borrowed_fd, owned_fd, ret, ret_c_int, ret_off_t, ret_owned_fd, ret_ssize_t},
+    conv::{borrowed_fd, ret, ret_c_int, ret_discarded_fd, ret_off_t, ret_owned_fd, ret_ssize_t},
     fs::{Access, FdFlags, Mode, OFlags, Stat},
     io::PollFd,
     offset::{libc_fstat, libc_fstatat, libc_lseek, libc_off_t, libc_pread, libc_pwrite},
     time::Timespec,
 };
-#[cfg(all(target_pointer_width = "64", target_os = "linux", target_env = "gnu"))]
+#[cfg(all(target_os = "linux", target_env = "gnu"))]
 use super::{
     io::ReadWriteFlags,
     offset::{libc_preadv2, libc_pwritev2},
 };
-use crate::{as_ptr, io};
+use crate::{
+    as_ptr,
+    io::{self, RawFd},
+};
 use errno::errno;
-use io_lifetimes::{BorrowedFd, OwnedFd};
+use io_lifetimes::{AsFd, BorrowedFd, OwnedFd};
 #[cfg(not(any(target_os = "wasi", target_os = "fuchsia")))]
 use std::ffi::OsString;
 #[cfg(target_os = "linux")]
@@ -117,7 +120,10 @@ use {
     std::path::PathBuf,
 };
 #[cfg(any(target_os = "android", target_os = "linux"))]
-use {super::fs::MemfdFlags, super::io::UserFaultFdFlags};
+use {
+    super::fs::MemfdFlags,
+    super::io::{EventfdFlags, UserfaultfdFlags},
+};
 #[cfg(not(target_os = "wasi"))]
 use {
     super::io::{DupFlags, MapFlags, ProtFlags, Termios, Winsize},
@@ -226,7 +232,7 @@ pub(crate) fn pwritev(fd: BorrowedFd<'_>, bufs: &[IoSlice], offset: u64) -> io::
     Ok(nwritten as usize)
 }
 
-#[cfg(all(target_pointer_width = "64", target_os = "linux", target_env = "gnu"))]
+#[cfg(all(target_os = "linux", target_env = "gnu"))]
 pub(crate) fn preadv2(
     fd: BorrowedFd<'_>,
     bufs: &[IoSliceMut],
@@ -247,7 +253,7 @@ pub(crate) fn preadv2(
     Ok(nread as usize)
 }
 
-#[cfg(all(target_pointer_width = "64", target_os = "linux", target_env = "gnu"))]
+#[cfg(all(target_os = "linux", target_env = "gnu"))]
 pub(crate) fn pwritev2(
     fd: BorrowedFd<'_>,
     bufs: &[IoSlice],
@@ -301,6 +307,10 @@ fn max_iov() -> usize {
     16 // The minimum value required by POSIX.
 }
 
+pub(crate) unsafe fn close(raw_fd: RawFd) {
+    let _ = libc::close(raw_fd as c_int);
+}
+
 #[cfg(not(target_os = "redox"))]
 pub(crate) fn openat(
     dirfd: BorrowedFd<'_>,
@@ -795,6 +805,11 @@ pub(crate) fn memfd_create(path: &CStr, flags: MemfdFlags) -> io::Result<OwnedFd
     }
 }
 
+#[cfg(any(target_os = "android", target_os = "linux"))]
+pub(crate) fn eventfd(initval: u32, flags: EventfdFlags) -> io::Result<OwnedFd> {
+    unsafe { syscall_ret_owned_fd(libc::syscall(libc::SYS_eventfd2, initval, flags.bits())) }
+}
+
 #[cfg(any(target_os = "android", target_os = "linux"))]
 pub(crate) fn openat2(
     dirfd: BorrowedFd<'_>,
@@ -906,6 +921,13 @@ pub(crate) fn ioctl_fionread(fd: BorrowedFd<'_>) -> io::Result<u64> {
     }
 }
 
+pub(crate) fn ioctl_fionbio(fd: BorrowedFd<'_>, value: bool) -> io::Result<()> {
+    unsafe {
+        let data = value as c_int;
+        ret(libc::ioctl(borrowed_fd(fd), libc::FIONBIO, &data))
+    }
+}
+
 pub(crate) fn isatty(fd: BorrowedFd<'_>) -> bool {
     let res = unsafe { libc::isatty(borrowed_fd(fd)) };
     if res == 0 {
@@ -989,8 +1011,8 @@ pub(crate) fn dup(fd: BorrowedFd<'_>) -> io::Result<OwnedFd> {
 }
 
 #[cfg(not(target_os = "wasi"))]
-pub(crate) fn dup2(fd: BorrowedFd<'_>, new: OwnedFd) -> io::Result<OwnedFd> {
-    unsafe { ret_owned_fd(libc::dup2(borrowed_fd(fd), owned_fd(new))) }
+pub(crate) fn dup2(fd: BorrowedFd<'_>, new: &OwnedFd) -> io::Result<()> {
+    unsafe { ret_discarded_fd(libc::dup2(borrowed_fd(fd), borrowed_fd(new.as_fd()))) }
 }
 
 #[cfg(not(any(
@@ -1000,8 +1022,14 @@ pub(crate) fn dup2(fd: BorrowedFd<'_>, new: OwnedFd) -> io::Result<OwnedFd> {
     target_os = "redox",
     target_os = "wasi"
 )))]
-pub(crate) fn dup2_with(fd: BorrowedFd<'_>, new: OwnedFd, flags: DupFlags) -> io::Result<OwnedFd> {
-    unsafe { ret_owned_fd(libc::dup3(borrowed_fd(fd), owned_fd(new), flags.bits())) }
+pub(crate) fn dup2_with(fd: BorrowedFd<'_>, new: &OwnedFd, flags: DupFlags) -> io::Result<()> {
+    unsafe {
+        ret_discarded_fd(libc::dup3(
+            borrowed_fd(fd),
+            borrowed_fd(new.as_fd()),
+            flags.bits(),
+        ))
+    }
 }
 
 #[cfg(any(
@@ -1010,7 +1038,7 @@ pub(crate) fn dup2_with(fd: BorrowedFd<'_>, new: OwnedFd, flags: DupFlags) -> io
     target_os = "ios",
     target_os = "redox"
 ))]
-pub(crate) fn dup2_with(fd: BorrowedFd<'_>, new: OwnedFd, _flags: DupFlags) -> io::Result<OwnedFd> {
+pub(crate) fn dup2_with(fd: BorrowedFd<'_>, new: &OwnedFd, _flags: DupFlags) -> io::Result<()> {
     // Android 5.0 has dup3, but libc doesn't have bindings
     dup2(fd, new)
 }
@@ -1125,7 +1153,7 @@ pub(crate) unsafe fn munmap(ptr: *mut c_void, len: usize) -> io::Result<()> {
     ret(libc::munmap(ptr, len))
 }
 
-#[cfg(any(target_os = "ios", target_os = "macos"))]
+#[cfg(not(target_os = "wasi"))]
 pub(crate) fn pipe() -> io::Result<(OwnedFd, OwnedFd)> {
     unsafe {
         let mut result = MaybeUninit::<[OwnedFd; 2]>::uninit();
@@ -1157,7 +1185,7 @@ pub(crate) fn poll(fds: &mut [PollFd<'_>], timeout: c_int) -> io::Result<usize>
 }
 
 #[cfg(any(target_os = "android", target_os = "linux"))]
-pub(crate) unsafe fn userfaultfd(flags: UserFaultFdFlags) -> io::Result<OwnedFd> {
+pub(crate) unsafe fn userfaultfd(flags: UserfaultfdFlags) -> io::Result<OwnedFd> {
     syscall_ret_owned_fd(libc::syscall(libc::SYS_userfaultfd, flags.bits()))
 }
 
