@@ -1,7 +1,9 @@
 mod dir;
+mod makedev;
 mod types;
 
 pub use dir::{Dir, DirEntry};
+pub use makedev::{major, makedev, minor};
 pub use types::{
     Access, Advice, AtFlags, Dev, FallocateFlags, FdFlags, FileType, FsWord, MemfdFlags, Mode,
     OFlags, RawMode, ResolveFlags, Stat, StatFs, Statx, StatxFlags, PROC_SUPER_MAGIC, UTIME_NOW,
