@@ -8,15 +8,16 @@ use std::os::raw::c_int;
 pub use imp::net::{AcceptFlags, AddressFamily, Protocol, Shutdown, SocketType};
 
 impl Default for Protocol {
+    #[inline]
     fn default() -> Self {
         Self::Ip
     }
 }
 
-/// `socket(domain, type_, protocol)`
+/// `socket(domain, type_, protocol)`—Creates a socket.
 ///
-/// Even though POSIX guarantees that this will use the lowest unused file
-/// descriptor, it is not safe in general to rely on this, as file descriptors
+/// POSIX guarantees that `socket` will use the lowest unused file descriptor,
+/// however it is not safe in general to rely on this, as file descriptors
 /// may be unexpectedly allocated on other threads or in libraries.
 ///
 /// # References
@@ -30,7 +31,8 @@ pub fn socket(domain: AddressFamily, type_: SocketType, protocol: Protocol) -> i
     imp::syscalls::socket(domain, type_, protocol)
 }
 
-/// `bind(sockfd, addr, sizeof(struct sockaddr_in))`
+/// `bind(sockfd, addr, sizeof(struct sockaddr_in))`—Binds a socket to an
+/// address.
 ///
 /// # References
 ///  - [POSIX]
@@ -45,7 +47,8 @@ pub fn bind_v4<Fd: AsFd>(sockfd: &Fd, addr: &SocketAddrV4) -> io::Result<()> {
     imp::syscalls::bind_v4(sockfd, addr)
 }
 
-/// `bind(sockfd, addr, sizeof(struct sockaddr_in6))`
+/// `bind(sockfd, addr, sizeof(struct sockaddr_in6))`—Binds a socket to an
+/// address.
 ///
 /// # References
 ///  - [POSIX]
@@ -60,7 +63,8 @@ pub fn bind_v6<Fd: AsFd>(sockfd: &Fd, addr: &SocketAddrV6) -> io::Result<()> {
     imp::syscalls::bind_v6(sockfd, addr)
 }
 
-/// `bind(sockfd, addr, sizeof(struct sockaddr_un))`
+/// `bind(sockfd, addr, sizeof(struct sockaddr_un))`—Binds a socket to an
+/// address.
 ///
 /// # References
 ///  - [POSIX]
@@ -75,7 +79,8 @@ pub fn bind_unix<Fd: AsFd>(sockfd: &Fd, addr: &SocketAddrUnix) -> io::Result<()>
     imp::syscalls::bind_unix(sockfd, addr)
 }
 
-/// `connect(sockfd, addr, sizeof(struct sockaddr_in))`
+/// `connect(sockfd, addr, sizeof(struct sockaddr_in))`—Initiates a
+/// connection.
 ///
 /// # References
 ///  - [POSIX]
@@ -90,7 +95,8 @@ pub fn connect_v4<Fd: AsFd>(sockfd: &Fd, addr: &SocketAddrV4) -> io::Result<()>
     imp::syscalls::connect_v4(sockfd, addr)
 }
 
-/// `connect(sockfd, addr, sizeof(struct sockaddr_in6))`
+/// `connect(sockfd, addr, sizeof(struct sockaddr_in6))`—Initiates a
+/// connection.
 ///
 /// # References
 ///  - [POSIX]
@@ -105,7 +111,8 @@ pub fn connect_v6<Fd: AsFd>(sockfd: &Fd, addr: &SocketAddrV6) -> io::Result<()>
     imp::syscalls::connect_v6(sockfd, addr)
 }
 
-/// `connect(sockfd, addr, sizeof(struct sockaddr_un))`
+/// `connect(sockfd, addr, sizeof(struct sockaddr_un))`—Initiates a
+/// connection.
 ///
 /// # References
 ///  - [POSIX]
@@ -120,7 +127,7 @@ pub fn connect_unix<Fd: AsFd>(sockfd: &Fd, addr: &SocketAddrUnix) -> io::Result<
     imp::syscalls::connect_unix(sockfd, addr)
 }
 
-/// `listen(fd, backlog)`
+/// `listen(fd, backlog)`—Enables listening for incoming connections.
 ///
 /// # References
 ///  - [POSIX]
@@ -134,13 +141,13 @@ pub fn listen<Fd: AsFd>(sockfd: &Fd, backlog: c_int) -> io::Result<()> {
     imp::syscalls::listen(sockfd, backlog)
 }
 
-/// `accept4(fd, NULL, NULL, flags)`
+/// `accept(fd, NULL, NULL)`—Accepts an incoming connection.
 ///
 /// Use [`acceptfrom`] to retrieve the peer address.
 ///
-/// Even though POSIX guarantees that this will use the lowest unused file
-/// descriptor, it is not safe in general to rely on this, as file descriptors
-/// may be unexpectedly allocated on other threads or in libraries.
+/// POSIX guarantees that `accept` will use the lowest unused file descriptor,
+/// however it is not safe in general to rely on this, as file descriptors may
+/// be unexpectedly allocated on other threads or in libraries.
 ///
 /// # References
 ///  - [POSIX]
@@ -150,12 +157,37 @@ pub fn listen<Fd: AsFd>(sockfd: &Fd, backlog: c_int) -> io::Result<()> {
 /// [Linux]: https://man7.org/linux/man-pages/man2/accept.2.html
 #[inline]
 #[doc(alias = "accept4")]
-pub fn accept<Fd: AsFd>(sockfd: &Fd, flags: AcceptFlags) -> io::Result<OwnedFd> {
+pub fn accept<Fd: AsFd>(sockfd: &Fd) -> io::Result<OwnedFd> {
     let sockfd = sockfd.as_fd();
-    imp::syscalls::accept(sockfd, flags)
+    imp::syscalls::accept(sockfd)
 }
 
-/// `accept4(fd, &addr, &len, flags)`
+/// `accept4(fd, NULL, NULL, flags)`—Accepts an incoming connection, with
+/// flags.
+///
+/// Use [`acceptfrom_with`] to retrieve the peer address.
+///
+/// Even though POSIX guarantees that this will use the lowest unused file
+/// descriptor, it is not safe in general to rely on this, as file descriptors
+/// may be unexpectedly allocated on other threads or in libraries.
+///
+/// `accept_with` is the same as `accept` but adds an additional flags operand.
+///
+/// # References
+///  - [POSIX]
+///  - [Linux]
+///
+/// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/accept.html
+/// [Linux]: https://man7.org/linux/man-pages/man2/accept4.2.html
+#[inline]
+#[doc(alias = "accept4")]
+pub fn accept_with<Fd: AsFd>(sockfd: &Fd, flags: AcceptFlags) -> io::Result<OwnedFd> {
+    let sockfd = sockfd.as_fd();
+    imp::syscalls::accept_with(sockfd, flags)
+}
+
+/// `accept(fd, &addr, &len)`—Accepts an incoming connection and returns the
+/// peer address.
 ///
 /// Use [`accept`] if the peer address isn't needed.
 ///
@@ -167,12 +199,36 @@ pub fn accept<Fd: AsFd>(sockfd: &Fd, flags: AcceptFlags) -> io::Result<OwnedFd>
 /// [Linux]: https://man7.org/linux/man-pages/man2/accept.2.html
 #[inline]
 #[doc(alias = "accept4")]
-pub fn acceptfrom<Fd: AsFd>(sockfd: &Fd, flags: AcceptFlags) -> io::Result<(OwnedFd, SocketAddr)> {
+pub fn acceptfrom<Fd: AsFd>(sockfd: &Fd) -> io::Result<(OwnedFd, SocketAddr)> {
     let sockfd = sockfd.as_fd();
-    imp::syscalls::acceptfrom(sockfd, flags)
+    imp::syscalls::acceptfrom(sockfd)
 }
 
-/// `shutdown(fd, how)`
+/// `accept4(fd, &addr, &len, flags)—Accepts an incoming connection and
+/// returns the peer address, with flags.
+///
+/// Use [`accept_with`] if the peer address isn't needed.
+///
+/// `acceptfrom_with` is the same as `acceptfrom` but adds an additional flags
+/// operand.
+///
+/// # References
+///  - [POSIX]
+///  - [Linux]
+///
+/// [POSIX]: https://pubs.opengroup.org/onlinepubs/9699919799/functions/accept.html
+/// [Linux]: https://man7.org/linux/man-pages/man2/accept4.2.html
+#[inline]
+#[doc(alias = "accept4")]
+pub fn acceptfrom_with<Fd: AsFd>(
+    sockfd: &Fd,
+    flags: AcceptFlags,
+) -> io::Result<(OwnedFd, SocketAddr)> {
+    let sockfd = sockfd.as_fd();
+    imp::syscalls::acceptfrom_with(sockfd, flags)
+}
+
+/// `shutdown(fd, how)`—Closes the read and/or write sides of a stream.
 ///
 /// # References
 ///  - [POSIX]
@@ -186,7 +242,7 @@ pub fn shutdown<Fd: AsFd>(sockfd: &Fd, how: Shutdown) -> io::Result<()> {
     imp::syscalls::shutdown(sockfd, how)
 }
 
-/// `getsockopt(fd, SOL_SOCKET, SO_TYPE)`
+/// `getsockopt(fd, SOL_SOCKET, SO_TYPE)`—Returns the type of a socket.
 ///
 /// # References
 ///  - [POSIX]
@@ -200,7 +256,7 @@ pub fn getsockopt_socket_type<Fd: AsFd>(fd: &Fd) -> io::Result<SocketType> {
     imp::syscalls::getsockopt_socket_type(fd)
 }
 
-/// `getsockname(fd, addr, len)`
+/// `getsockname(fd, addr, len)`—Returns the address a socket is bound to.
 ///
 /// # References
 ///  - [POSIX]
@@ -214,7 +270,8 @@ pub fn getsockname<Fd: AsFd>(sockfd: &Fd) -> io::Result<SocketAddr> {
     imp::syscalls::getsockname(sockfd)
 }
 
-/// `getpeername(fd, addr, len)`
+/// `getpeername(fd, addr, len)`—Returns the address a socket is connected
+/// to.
 ///
 /// # References
 ///  - [POSIX]
